@@ -1,9 +1,11 @@
 package Util::Medley::Cache;
-$Util::Medley::Cache::VERSION = '0.002';
+$Util::Medley::Cache::VERSION = '0.003';
 use Modern::Perl;
 use Moose;
 use Method::Signatures;
 use namespace::autoclean;
+
+use Carp;
 use CHI;
 use File::Path 'remove_tree';
 use Data::Printer alias => 'pdump';
@@ -16,7 +18,7 @@ Util::Medley::Cache - Simple caching mechanism.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =cut
 
@@ -71,7 +73,9 @@ Location of the L2 file cache.
 
 =over
 
-=item default: $HOME/.util-medley/cache
+=item default
+
+$HOME/.util-medley/cache
 
 =back
 
@@ -90,7 +94,9 @@ Toggles caching on or off.
 
 =over
 
-=item default: 1
+=item default
+
+1
 
 =back
 
@@ -107,9 +113,13 @@ has enabled => (
 
 Sets the cache expiration.  
 
-Default: 0 (never)
+=over
 
-Env Var: MEDLEY_CACHE_DISABLED
+=item default
+
+0 (never)
+
+=back
 
 =cut
 
@@ -136,9 +146,17 @@ has namespace => (
 
 Toggles the L1 cache on or off.
 
-Default: 1
+=over
 
-Env Var: MEDLEY_CACHE_L1_DISABLED
+=item default
+
+1
+
+=item env var
+
+To disable L1 cache, set MEDLEY_CACHE_L1_DISABLED=1.
+
+=back
 
 =cut
 
@@ -153,9 +171,17 @@ has l1Enabled => (
 
 Toggles the L2 cache on or off.
 
-Default: 1
+=over
 
-Env Var: MEDLEY_CACHE_L2_DISABLED
+=item default
+
+1
+
+=item env var
+
+To disable L2 cache, set MEDLEY_CACHE_L2_DISABLED=1.
+
+=back
 
 =cut
 
@@ -188,15 +214,21 @@ has _l1Cache => (
 
 Clears all cache for a given namespace.
 
-=head3 usage:
+=over
+
+=item usage:
 
  clear( [ namespace => $ns ] )
 
-=head3 args:
+=item args:
 
 =over
 
-=item * namespace: The cache namespace.
+=item namespace [Str]
+
+The cache namespace.
+
+=back
 
 =back
 
@@ -214,20 +246,28 @@ method clear (Str :$namespace) {
 
 Deletes a cache object.
 
-=head3 usage:
+=over
+
+=item usage:
 
  delete(
-      key       => <string>,
-    [ namespace => <string> ]
+      key       => $key
+    [ namespace => $ns ]
  )
-  
-=head3 args:
+
+=item args:
 
 =over
 
-=item * key: Unique identifier of the cache object.
+=item key [Str]
 
-=item * namespace: The cache namespace.
+Unique identifier of the cache object.
+
+=item namespace [Str] 
+
+The cache namespace. 
+
+=back
 
 =back
 
@@ -246,15 +286,21 @@ method delete (Str :$key!,
 
 Deletes L1 cache and removes L2 from disk completely.
 
-=head3 usage:
+=over
 
- destroy( [namespace => $ns] )
+=item usage:
+
+ destroy( [ namespace => $ns ] )
   
-=head3 args:
+=item args:
 
 =over
 
-=item * namespace: The cache namespace.  
+=item namespace [Str]
+
+The cache namespace.  
+
+=back
 
 =back
 
@@ -272,20 +318,28 @@ method destroy (Str :$namespace) {
 
 Gets a unique cache object.  Returns undef if not found.
 
-=head3 usage:
+=over
+
+=item usage:
 
  get(
       key       => $key,
     [ namespace => $ns ]
  )
  
-=head3 args:
+=item args:
 
 =over
 
-=item * key: Unique identifier of the cache object.
+=item key [Str]
 
-=item * namespace: The cache namespace.  
+Unique identifier of the cache object.
+
+=item namespace [Str]
+
+The cache namespace.  
+
+=back
 
 =back
 
@@ -314,15 +368,21 @@ method get (Str :$namespace,
 
 Gets the L2 cache dir.
 
-=head3 usage:
+=over
+
+=item usage:
 
  getNamespaceDir( [ namespace => $ns ] )
  
-=head3 args:
+=item args:
 
 =over
 
-=item * namespace: The cache namespace.  
+=item namespace [Str]
+
+The cache namespace.  
+
+=back
 
 =back
 
@@ -341,7 +401,9 @@ method getNamespaceDir (Str $namespace?) {
 
 Commits the data object to the cache.
 
-=head3 usage:
+=over
+
+=item usage:
 
  set(
       key       => $key,
@@ -349,15 +411,23 @@ Commits the data object to the cache.
     [ namespace => $ns ],
  )
    
-=head3 args:
+=item args:
 
 =over
 
-=item * key: Unique identifier of the cache object.
+=item key [Str]
 
-=item * data: An object, reference, or string.
+Unique identifier of the cache object.
 
-=item * namespace: The cache namespace.  
+=item data [Object|Ref|Str]
+
+An object, reference, or string.
+
+=item namespace [Str]
+
+The cache namespace.  
+
+=back
 
 =back
 
@@ -377,15 +447,21 @@ method set (Str :$key!,
 
 Returns a list of cache keys.
 
-=head3 usage:
+=over
+
+=item usage:
 
  getKeys( [ namespace => $ns ] )
  
-=head3 args:
+=item args:
 
 =over
 
-=item * namespace: The cache namespace.  
+=item namespace [Str]
+
+The cache namespace.  
+
+=back
 
 =back
 
